==> eui-76.1.0.tgz: package/optimize/es/components/delay_hide/delay_hide.a11y.js <==
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";

/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */
/// <reference types="../../../cypress/support"/>
import React, { useState } from 'react';
import { EuiDelayHide } from './delay_hide';
import { EuiCheckbox, EuiFieldNumber, EuiFormRow } from '../form';
import { EuiFlexItem } from '../flex';
import { EuiLoadingSpinner } from '../loading';
import { jsx as ___EmotionJSX } from "@emotion/react";

var DelayHide = function DelayHide() {
  var _useState = useState(1000),
      _useState2 = _slicedToArray(_useState, 2),
      minimumDuration = _useState2[0],
      setDuration = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      hide = _useState4[0],
      setHide = _useState4[1];

  var onChangeMinimumDuration = function onChangeMinimumDuration(event) {
    setDuration(parseInt(event.target.value, 10));
  };

  var onChangeHide = function onChangeHide(event) {
    setHide(event.target.checked);
  };

  return ___EmotionJSX(React.Fragment, null, ___EmotionJSX(EuiFlexItem, null, ___EmotionJSX(EuiFormRow, null, ___EmotionJSX(EuiCheckbox, {
    id: "dummy-id",
    checked: hide,
    onChange: onChangeHide,
    label: "Hide child"
  })), ___EmotionJSX(EuiFormRow, {
    label: "Minimum duration"
  }, ___EmotionJSX(EuiFieldNumber, {
    value: minimumDuration,
    onChange: onChangeMinimumDuration
  })), ___EmotionJSX(EuiFormRow, {
    label: "Child to render"
  }, ___EmotionJSX(EuiDelayHide, {
    hide: hide,
    minimumDuration: minimumDuration,
    render: function render() {
      return ___EmotionJSX(EuiLoadingSpinner, {
        size: "m"
      });
    }
  }))));
};

beforeEach(function () {
  cy.realMount(___EmotionJSX(DelayHide, null));
});
describe('EuiHideRender', function () {
  describe('Automated accessibility check', function () {
    it('has zero violations on first render', function () {
      cy.checkAxe();
    });
    it('has zero violations when the hide child input is checked', function () {
      cy.get('input.euiCheckbox__input').realClick();
      cy.get('div.euiFormRow__fieldWrapper').last().find('span[role="progressbar"]', {
        timeout: 5000
      }).should('not.exist');
      cy.checkAxe();
    });
    it('has zero violations when the hide child input is pressed', function () {
      cy.realPress('Tab');
      cy.get('input.euiCheckbox__input').should('have.focus');
      cy.realPress('Space');
      cy.get('div.euiFormRow__fieldWrapper').last().find('span[role="progressbar"]', {
        timeout: 5000
      }).should('not.exist');
      cy.checkAxe();
    });
    it('has zero violations when the hide child input is toggled', function () {
      cy.realPress('Tab');
      cy.get('input.euiCheckbox__input').should('have.focus');
      cy.realPress('Space');
      cy.get('div.euiFormRow__fieldWrapper').last().find('span[role="progressbar"]').should('not.exist');
      cy.realPress('Space');
      cy.get('div.euiFormRow__fieldWrapper').last().find('span[role="progressbar"]', {
        timeout: 5000
      }).should('exist');
      cy.checkAxe();
    });
  });
});

==> eui-95.7.0.tgz: package/optimize/es/components/delay_hide/delay_hide.a11y.js <==
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

/// <reference types="cypress" />
/// <reference types="cypress-real-events" />
/// <reference types="../../../cypress/support" />

import React, { useState } from 'react';
import { EuiDelayHide } from './delay_hide';
import { EuiCheckbox, EuiFieldNumber, EuiFormRow } from '../form';
import { EuiFlexItem } from '../flex';
import { EuiLoadingSpinner } from '../loading';
import { jsx as ___EmotionJSX } from "@emotion/react";
var DelayHide = function DelayHide() {
  var _useState = useState(1000),
    _useState2 = _slicedToArray(_useState, 2),
    minimumDuration = _useState2[0],
    setDuration = _useState2[1];
  var _useState3 = useState(false),
    _useState4 = _slicedToArray(_useState3, 2),
    hide = _useState4[0],
    setHide = _useState4[1];
  return ___EmotionJSX(React.Fragment, null, ___EmotionJSX(EuiFlexItem, null, ___EmotionJSX(EuiFormRow, null, ___EmotionJSX(EuiCheckbox, {
    id: "dummy-id",
    checked: hide,
    onChange: function onChange(event) {
      return setHide(event.target.checked);
    },
    label: "Hide child"
  })), ___EmotionJSX(EuiFormRow, {
    label: "Minimum duration"
  }, ___EmotionJSX(EuiFieldNumber, {
    value: minimumDuration,
    onChange: function onChange(event) {
      return setDuration(parseInt(event.target.value, 10));
    }
  })), ___EmotionJSX(EuiFormRow, {
    label: "Child to render"
  }, ___EmotionJSX(EuiDelayHide, {
    hide: hide,
    minimumDuration: minimumDuration,
    render: function render() {
      return ___EmotionJSX(EuiLoadingSpinner, {
        size: "m"
      });
    }
  }))));
};
beforeEach(function () {
  cy.realMount(___EmotionJSX(DelayHide, null));
});
describe('EuiHideRender', function () {
  describe('Automated accessibility check', function () {
    it('has zero violations on first render', function () {
      cy.checkAxe();
    });
    it('has zero violations when the hide child input is checked', function () {
      cy.get('input.euiCheckbox__input').realClick();
      cy.get('div.euiFormRow__fieldWrapper').last().find('span[role="progressbar"]', {
        timeout: 5000
      }).should('not.exist');
      cy.checkAxe();
    });
    it('has zero violations when the hide child input is pressed', function () {
      cy.realPress('Tab');
      cy.get('input.euiCheckbox__input').should('have.focus');
      cy.realPress('Space');
      cy.get('div.euiFormRow__fieldWrapper').last().find('span[role="progressbar"]', {
        timeout: 5000
      }).should('not.exist');
      cy.checkAxe();
    });
    it('has zero violations when the hide child input is toggled', function () {
      cy.realPress('Tab');
      cy.get('input.euiCheckbox__input').should('have.focus');
      cy.realPress('Space');
      cy.get('div.euiFormRow__fieldWrapper').last().find('span[role="progressbar"]').should('not.exist');
      cy.realPress('Space');
      cy.get('div.euiFormRow__fieldWrapper').last().find('span[role="progressbar"]', {
        timeout: 5000
      }).should('exist');
      cy.checkAxe();
    });
  });
});
